@@ -9,8 +9,8 @@
  *    Change Date     :
  */
 define([
-    '!!text-loader!vp_base/html/component/dataSelector.html', // LAB: text! to text-loader
-    'vp_base/css/component/dataSelector.css', // LAB: css! to css-loader
+    '!!text-loader!vp_base/html/component/dataSelector.html', // INTEGRATION: unified version of text loader
+    'vp_base/css/component/dataSelector.css', // INTEGRATION: unified version of css loader
     'vp_base/js/com/com_Const',
     'vp_base/js/com/com_String',
     'vp_base/js/com/com_util',
